pub fn normalize_mail_name_config_value(value: &str) -> MailConfigResult<String>Expand description
Normalizes a sender display name value.
Errors
Returns MailConfigError when the supplied value violates the corresponding mail setting contract.
pub fn normalize_mail_name_config_value(value: &str) -> MailConfigResult<String>Normalizes a sender display name value.
Returns MailConfigError when the supplied value violates the corresponding mail setting contract.