pub fn normalize_smtp_port_config_value(value: &str) -> MailConfigResult<String>Expand description
Normalizes an SMTP port value.
Errors
Returns MailConfigError when the supplied value violates the corresponding mail setting contract.
pub fn normalize_smtp_port_config_value(value: &str) -> MailConfigResult<String>Normalizes an SMTP port value.
Returns MailConfigError when the supplied value violates the corresponding mail setting contract.