pub struct StoredMailPayload(pub String);Expand description
Raw JSON payload stored in mail_outbox.payload_json.
Tuple Fields
0: StringImplementations
Sourceimpl StoredMailPayload
impl StoredMailPayload
Sourcepub const CLEARED_JSON: &str = "{}"
pub const CLEARED_JSON: &str = "{}"
Payload value persisted after terminal delivery, so sensitive template variables do not remain in the outbox row.