pub enum MailTemplateRegistryError {
EmptyTemplateCode,
DuplicateTemplateCode {
code: &'static str,
},
EmptyVariableKey {
template_code: &'static str,
},
DuplicateVariableKey {
template_code: &'static str,
key: &'static str,
},
}Expand description
Validation error returned when a template registry has ambiguous registrations.
Variants
EmptyTemplateCode
A template code is empty.
DuplicateTemplateCode
The same template code was registered more than once.
EmptyVariableKey
A variable key is empty for a template.
DuplicateVariableKey
The same variable key was registered more than once for one template.