pub fn render_template(
subject_template: &str,
html_template: &str,
placeholders: &TemplatePlaceholderSet,
) -> RenderedMailExpand description
Renders a subject and HTML template with placeholder values and derives text fallback.
pub fn render_template(
subject_template: &str,
html_template: &str,
placeholders: &TemplatePlaceholderSet,
) -> RenderedMailRenders a subject and HTML template with placeholder values and derives text fallback.