pub struct TemplatePlaceholderSet { /* private fields */ }Expand description
Placeholder values for a render pass.
Implementations
Sourceimpl TemplatePlaceholderSet
impl TemplatePlaceholderSet
Sourcepub fn new(
text_values: Vec<(&'static str, String)>,
html_values: Vec<(&'static str, String)>,
) -> Self
pub fn new( text_values: Vec<(&'static str, String)>, html_values: Vec<(&'static str, String)>, ) -> Self
Creates a placeholder set from separate text and HTML values.
Sourcepub fn text_values(&self) -> &[(&'static str, String)]
pub fn text_values(&self) -> &[(&'static str, String)]
Returns placeholder values for plain text and subject rendering.
Sourcepub fn html_values(&self) -> &[(&'static str, String)]
pub fn html_values(&self) -> &[(&'static str, String)]
Returns placeholder values for HTML rendering.