pub type MailTemplateRegistrar = fn(&mut MailTemplateCatalogBuilder);Expand description
Function exported by a product subsystem to register its mail templates.
pub type MailTemplateRegistrar = fn(&mut MailTemplateCatalogBuilder);Function exported by a product subsystem to register its mail templates.